@@ -11,7 +11,7 @@ from typing import Optional, Union, Callable, Any, List, Literal, Dict
 
 from loguru import logger
 
-from bricks.core.context import Context
+from bricks.core.context import Context, Flow
 from bricks.utils import pandora
 
 
@@ -21,6 +21,7 @@ class RegisteredEvents:
         self.permanent = defaultdict(functools.partial(defaultdict, list))
         # 一次性事件
         self.disposable = defaultdict(functools.partial(defaultdict, list))
+        self.lazy_loading = defaultdict(functools.partial(defaultdict, list))
 
         self.registed: Dict[str, List[Register]] = defaultdict(list)
 
@@ -92,27 +93,48 @@ class EventManager:
     counter = defaultdict(itertools.count)
 
     @classmethod
-    def trigger(cls, context: Context, errors: Literal['raise', 'ignore', 'output'] = "raise"):
+    def trigger(cls, context: Context, errors: Literal['raise', 'ignore', 'output'] = "raise", annotations: dict = None,
+                namespace: dict = None):
         """
         trigger events: interact with external functions
 
         """
 
         for event in cls.acquire(context):
-            yield cls._call(event, context, errors=errors)
+            yield cls._call(event, context, errors=errors, annotations=annotations, namespace=namespace)
 
     @classmethod
-    def invoke(cls, context: Context, errors: Literal['raise', 'ignore', 'output'] = "raise"):
+    def invoke(cls, context: Context, errors: Literal['raise', 'ignore', 'output'] = "raise", annotations: dict = None,
+               namespace: dict = None):
         """
         invoke events: invoke all events
 
+        :param namespace:
+        :param annotations:
         :param errors:
         :param context:
         :return:
         """
-        for _ in cls.trigger(context, errors=errors):
+        for _ in cls.trigger(context, errors=errors, annotations=annotations, namespace=namespace):
             pass
 
+    @classmethod
+    def next(
+            cls,
+            ctx: Flow,
+            form: str,
+            annotations: dict = None,
+            namespace: dict = None,
+            callback: Callable = None
+    ):
+        def main(context: Flow):
+            EventManager.invoke(context, annotations=annotations, namespace=namespace)
+            callback and callback(context)
+
+        ctx.form = form
+        ctx.flow({"next": main})
+        return main
+
     @classmethod
     def acquire(cls, context: Context):
         if context.target is None:
@@ -145,14 +167,17 @@ class EventManager:
                         yield event
 
     @classmethod
-    def _call(cls, event: Task, context: Context, errors: Literal['raise', 'ignore', 'output'] = "raise"):
+    def _call(cls, event: Task, context: Context, errors: Literal['raise', 'ignore', 'output'] = "raise",
+              annotations: dict = None, namespace: dict = None):
         try:
+            annotations = annotations or {}
+            namespace = namespace or {}
             return pandora.invoke(
                 event.func,
                 args=event.args,
                 kwargs=event.kwargs,
-                annotations={type(context): context},
-                namespace={"context": context}
+                annotations={type(context): context, **annotations},
+                namespace={"context": context, **namespace}
             )
         except Exception as e:
             if errors == "raise":
@@ -210,12 +235,17 @@ def on(form: str, index: int = None, disposable: Optional[bool] = False, binding
     def inner(func):
         if binding is ...:
             if "." in func.__qualname__:
-                setattr(func, "$event", (form, Task(func=func.__name__, index=index, disposable=disposable)))
+                REGISTERED_EVENTS.lazy_loading[func.__qualname__.rsplit('.', 1)[0]][form].append(Task(func=func.__name__, index=index, disposable=disposable))
             else:
-                EventManager.register(Context(form=form), Task(func=func, index=index, disposable=disposable))
+                EventManager.register(
+                    Context(form=form),
+                    Task(func=func, index=index, disposable=disposable)
+                )
         else:
-            EventManager.register(Context(form=form, target=binding),
-                                  Task(func=func, index=index, disposable=disposable))
+            EventManager.register(
+                Context(form=form, target=binding),
+                Task(func=func, index=index, disposable=disposable))
+
         return func
 
     return inner
