@@ -94,8 +94,12 @@ class Download(RenderNode):
     proxies: Optional[str] = None
     # proxy: 代理 Key, 理解为 proxy from
     proxy: Optional[dict] = None
-    # 判断成功动态脚本, 字符串形式, 如通过 403 状态码可以写为: 200 <= response.status_code < 400 or response.status_code == 403
-    ok: Optional[str] = ...
+    # 判断成功动态脚本, 字符串形式 / 字典形式 /
+    # 字符串形式, 如通过 403 状态码可以写为: 200 <= response.status_code < 400 or response.status_code == 403
+    # 字典形式, 如 {"response.status_code == 404": signals.Success}, 标识状态码为 404 的时候直接删除种子
+    # 字典形式, 如 {"response.status_code == 403": signals.Pass}, 标识状态码为 403 的时候让其通过默认的拦截器
+    # 字典形式, 如 {"response.status_code == 403": Callable Func}, 标识状态码为 403 的时候让Callable Func 来处理后续逻辑
+    ok: Optional[Union[str, Dict[str, Union[type(signals.Signal), Callable]]]] = ...
     # 当前重试次数
     retry: int = 0
     # 最大重试次数
@@ -193,7 +197,7 @@ class Spider(air.Spider):
             except IndexError:
                 context.flow({"next": None})
 
-                raise signals.Switch
+                raise signals.Switch()
             else:
                 context.seeds['$signpost'] += 1
 
@@ -207,18 +211,18 @@ class Spider(air.Spider):
                         context.seeds['$bookmark'] = signpost
                         node.archive and context.archive(signpost)
                         context.flow({"next": self.make_request})
-                    raise signals.Switch
+                    raise signals.Switch()
 
                 # Request -> Response
                 elif isinstance(node, Parse):
                     node.archive and context.archive(signpost)
                     context.flow({"next": self.on_response})
-                    raise signals.Switch
+                    raise signals.Switch()
 
                 elif isinstance(node, Pipeline):
                     node.archive and context.archive(signpost)
                     context.flow({"next": self.on_pipeline})
-                    raise signals.Switch
+                    raise signals.Switch()
 
                 elif isinstance(node, Task):
                     node.archive and context.archive(signpost)
