@@ -17,13 +17,25 @@ import re
 import subprocess
 import sys
 import threading
-from typing import Any, List, Union, Mapping, Callable, Literal, Tuple
+from typing import Any, List, Union, Mapping, Callable, Literal, Tuple, Dict
 
 import better_exceptions
 from loguru import logger
 
 JSONP_REGEX = re.compile(r'\S+?\((?P<obj>[\s\S]*)\)')
-PACKAGE_REGEX = re.compile(r"([a-zA-Z0-9_\-]+)([<>=]*)([\d.]*)")
+PACKAGE_REGEX = re.compile(r"([a-zA-Z0-9_\-]+)([<>=]*)(.*)")
+
+# 一般而言, 是一个以 simple 结尾的 url
+PIPY_REGEX = re.compile(r"https?://.*/simple/?$")
+PYPI_MIRROR = {
+    "TUNA": "https://pypi.tuna.tsinghua.edu.cn/simple",
+    "USTC": "http://pypi.mirrors.ustc.edu.cn/simple/",
+    "Aliyun": "http://mirrors.aliyun.com/pypi/simple/",
+    "Tencent": "https://mirrors.cloud.tencent.com/pypi/simple/",
+    "Huawei": "https://repo.huaweicloud.com/repository/pypi/simple/",
+    "pypi": "https://pypi.org/simple/"
+}
+
 
 better_exceptions.MAX_LENGTH = None
 exec_formatter = better_exceptions.ExceptionFormatter(
@@ -83,18 +95,28 @@ def load_objects(path_or_reference, reload=False):
 
 def require(
         package_spec: str,
-        action: Literal["raise", "fix"] = "fix"
+        action: Literal["raise", "fix"] = "fix",
+        mirror_sources: str = "TUNA",
+        pip_kwargs: Dict[str, str] = None
 ) -> str:
     """
     依赖 python 包
 
-    :param action:
+    :param action: 依赖操作, 若为 fix 则自动下载对应包,
     :param package_spec: pymongo==4.6.0 / pymongo
+    :param mirror_sources : pip 源, 内置有 "TUNA", "USTC", "Aliyun", "Tencent", "Huawei", "pypi", 可以传自己的源进来
+    :param pip_kwargs: pip 的一些参数, 如 --trusted-host, 单独的参数可以使用 {"--upgrade": ""} 这种方式
     :return: 安装的包版本号
     """
     # 分离包名和版本规范
+    package_spec = re.sub(r"\s+", "", package_spec)
     match = PACKAGE_REGEX.match(package_spec)
-    assert match, ValueError("无效的包规范")
+    mirror_sources = PYPI_MIRROR.get(mirror_sources, mirror_sources)
+    pip_kwargs = pip_kwargs or {}
+
+    assert match, ValueError(f"无效的包规范: {package_spec}")
+    assert not mirror_sources or PIPY_REGEX.match(mirror_sources), ValueError(f"无效的镜像源: {mirror_sources}")
+    mirror_sources and pip_kwargs.setdefault('-i', mirror_sources)
 
     package, operator, required_version = match.groups()
 
@@ -102,7 +124,9 @@ def require(
         # 获取已安装的包版本
         installed_version = importlib_metadata.version(package)
         # 检查是否需要安装或更新
-        if required_version and not eval(f'{installed_version!r} {operator} {required_version!r}'):
+        from bricks.utils.package import parse as version_parse  # noqa
+        if required_version and not eval(
+                f'version_parse({installed_version!r}) {operator} version_parse({required_version!r})'):
             raise importlib_metadata.PackageNotFoundError
         else:
             return installed_version
@@ -111,7 +135,11 @@ def require(
 
         # 包没有安装或版本不符合要求
         install_command = package_spec if required_version else package
-        cmd = [sys.executable, "-m", "pip", "install", install_command]
+        cmd = [sys.executable, "-m", "pip", "install"]
+        for k, v in pip_kwargs.items():
+            k and cmd.append(k)
+            v and cmd.append(v)
+        cmd.append(install_command)
         if action == "raise":
             raise importlib_metadata.PackageNotFoundError(f"依赖包不符合要求, 请使用以下命令安装: {' '.join(cmd)}")
         else:
